[Libreoffice-commits] core.git: cui/source dtrans/source editeng/qa editeng/source include/i18nlangtag include/svtools include/xmloff postprocess/packimages sc/source sfx2/qa slideshow/source starmath/source svx/source sw/source writerfilter/source

Andrea Gelmini andrea.gelmini at gelma.net
Mon Jun 26 07:20:39 UTC 2017


 cui/source/tabpages/labdlg.cxx                                |    4 ++--
 cui/source/tabpages/measure.cxx                               |    2 +-
 dtrans/source/win32/misc/ImplHelper.cxx                       |    2 +-
 editeng/qa/unit/core-test.cxx                                 |    2 +-
 editeng/source/editeng/impedit4.cxx                           |    6 +++---
 include/i18nlangtag/mslangid.hxx                              |    2 +-
 include/svtools/brwbox.hxx                                    |    2 +-
 include/xmloff/xmlprhdl.hxx                                   |    2 +-
 postprocess/packimages/image-sort.lst                         |    2 +-
 sc/source/filter/xcl97/xcl97rec.cxx                           |    2 +-
 sc/source/ui/docshell/externalrefmgr.cxx                      |    2 +-
 sfx2/qa/python/check_sidebar_registry.py                      |    4 ++--
 slideshow/source/engine/animationnodes/animationaudionode.cxx |    2 +-
 starmath/source/visitors.cxx                                  |    2 +-
 svx/source/fmcomp/fmgridcl.cxx                                |    2 +-
 sw/source/core/ole/ndole.cxx                                  |    2 +-
 sw/source/filter/html/htmlnumreader.cxx                       |    2 +-
 sw/source/filter/html/htmltab.cxx                             |    6 +++---
 writerfilter/source/dmapper/DomainMapper.cxx                  |    2 +-
 19 files changed, 25 insertions(+), 25 deletions(-)

New commits:
commit dbcc169d8c1008d46f62e0a526aa89331471621a
Author: Andrea Gelmini <andrea.gelmini at gelma.net>
Date:   Sun Jun 25 23:38:18 2017 +0200

    Fix typos
    
    Change-Id: I2ce725f87ee6f8ebcffbac268cc7e7f8850023e5
    Reviewed-on: https://gerrit.libreoffice.org/39232
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/cui/source/tabpages/measure.cxx b/cui/source/tabpages/measure.cxx
index 8f90eac08a6d..c502e077f08d 100644
--- a/cui/source/tabpages/measure.cxx
+++ b/cui/source/tabpages/measure.cxx
@@ -597,7 +597,7 @@ bool SvxMeasurePage::FillItemSet( SfxItemSet* rAttrs)
 
 void SvxMeasurePage::Construct()
 {
-    DBG_ASSERT( pView, "No valid View transfered!" );
+    DBG_ASSERT( pView, "No valid View transferred!" );
 
     m_pCtlPreview->pMeasureObj->SetModel( pView->GetModel() );
     m_pCtlPreview->Invalidate();
diff --git a/dtrans/source/win32/misc/ImplHelper.cxx b/dtrans/source/win32/misc/ImplHelper.cxx
index e4e8d1cb0ba7..58836ec6c601 100644
--- a/dtrans/source/win32/misc/ImplHelper.cxx
+++ b/dtrans/source/win32/misc/ImplHelper.cxx
@@ -338,7 +338,7 @@ bool SAL_CALL CompareTargetDevice( DVTARGETDEVICE* ptdLeft, DVTARGETDEVICE* ptdR
             bRet = true;
         }
 
-        // one ot the two is NULL
+        // one of the two is NULL
         else if ( ( nullptr != ptdRight ) && ( nullptr != ptdLeft ) )
 
         if ( ptdLeft->tdSize == ptdRight->tdSize )
diff --git a/editeng/qa/unit/core-test.cxx b/editeng/qa/unit/core-test.cxx
index ba76dd885ae8..165ec4b7d952 100644
--- a/editeng/qa/unit/core-test.cxx
+++ b/editeng/qa/unit/core-test.cxx
@@ -75,7 +75,7 @@ public:
     /// Test Copy/Paste with Underline text using Legacy Format
     void testUnderlineCopyPaste();
 
-    /// Test Copy/Paste with mutiple paragraphs
+    /// Test Copy/Paste with multiple paragraphs
     void testMultiParaCopyPaste();
 
     void testSectionAttributes();
diff --git a/editeng/source/editeng/impedit4.cxx b/editeng/source/editeng/impedit4.cxx
index 660b4b506319..4918ee36a370 100644
--- a/editeng/source/editeng/impedit4.cxx
+++ b/editeng/source/editeng/impedit4.cxx
@@ -499,18 +499,18 @@ ErrCode ImpEditEngine::WriteRTF( SvStream& rOutput, EditSelection aSel )
                     rOutput.WriteUInt32AsString( nNumber );
                 }
 
-                // Next Style ... (more)
+                // Next Style... (more)
                 // we assume that we have only SfxStyleSheet in the pool
                 SfxStyleSheet* pNext = static_cast<SfxStyleSheet*>(pStyle);
                 if ( !pStyle->GetFollow().isEmpty() && ( pStyle->GetFollow() != pStyle->GetName() ) )
                     pNext = static_cast<SfxStyleSheet*>(GetStyleSheetPool()->Find( pStyle->GetFollow(), pStyle->GetFamily() ));
 
-                DBG_ASSERT( pNext, "Next ot found!" );
+                DBG_ASSERT( pNext, "Next not found!" );
                 rOutput.WriteCharPtr( OOO_STRING_SVTOOLS_RTF_SNEXT );
                 nNumber = aStyleSheetToIdMap.find(pNext)->second;
                 rOutput.WriteUInt32AsString( nNumber );
 
-                // Name of the template ...
+                // Name of the template...
                 rOutput.WriteCharPtr( " " );
                 RTFOutFuncs::Out_String( rOutput, pStyle->GetName(), eDestEnc );
                 rOutput.WriteCharPtr( ";}" );
diff --git a/include/i18nlangtag/mslangid.hxx b/include/i18nlangtag/mslangid.hxx
index b38e01d829fc..c9851e098e1c 100644
--- a/include/i18nlangtag/mslangid.hxx
+++ b/include/i18nlangtag/mslangid.hxx
@@ -166,7 +166,7 @@ public:
      */
     static LanguageType getReplacementForObsoleteLanguage( LanguageType nLang );
 
-    /** Whether locale is legacy, i.e. country ot confederation doesn't exist anymore. */
+    /** Whether locale is legacy, i.e. country or confederation doesn't exist anymore. */
     static bool isLegacy( LanguageType nLang );
 
 
diff --git a/include/svtools/brwbox.hxx b/include/svtools/brwbox.hxx
index 2f21d512781c..a5eee89784fe 100644
--- a/include/svtools/brwbox.hxx
+++ b/include/svtools/brwbox.hxx
@@ -599,7 +599,7 @@ public:
             bool _bColumnHeaderBar
          );
 
-    /** returns the Rectangle for either the column header bar ot the row header bar
+    /** returns the Rectangle for either the column header bar or the row header bar
         @param  _bIsColumnBar
             <TRUE/> when column header bar is used
         @param  _bOnScreen
diff --git a/include/xmloff/xmlprhdl.hxx b/include/xmloff/xmlprhdl.hxx
index bc46a978a859..0aba91b432f4 100644
--- a/include/xmloff/xmlprhdl.hxx
+++ b/include/xmloff/xmlprhdl.hxx
@@ -48,7 +48,7 @@ public:
 
     /// Imports the given value in cas of the given XML-data-type
     virtual bool importXML( const OUString& rStrImpValue, css::uno::Any& rValue, const SvXMLUnitConverter& rUnitConverter ) const =0;
-    /// Exports the given value in cas of the given XML-data-type
+    /// Exports the given value in case of the given XML-data-type
     virtual bool exportXML( OUString& rStrExpValue, const css::uno::Any& rValue, const SvXMLUnitConverter& rUnitConverter ) const =0;
 };
 
diff --git a/postprocess/packimages/image-sort.lst b/postprocess/packimages/image-sort.lst
index 9d8cf0819eba..df4bb3c0ad7f 100644
--- a/postprocess/packimages/image-sort.lst
+++ b/postprocess/packimages/image-sort.lst
@@ -3,7 +3,7 @@
 # icons inside the OO.o theme / images.zip file.
 #
 # Sections are processed together, and are delimited
-# by '-- <tag> [small]' a 'group' tage denotes equal
+# by '-- <tag> [small]' a 'group' tag denotes equal
 # importance: icons must be interleaved, 'ordered'
 # denotes a simple best-fit order. 'literal' denotes
 # a list of explicit image loads
diff --git a/sc/source/filter/xcl97/xcl97rec.cxx b/sc/source/filter/xcl97/xcl97rec.cxx
index 30fc08bd9af4..951bf09bd53c 100644
--- a/sc/source/filter/xcl97/xcl97rec.cxx
+++ b/sc/source/filter/xcl97/xcl97rec.cxx
@@ -379,7 +379,7 @@ void XclObj::ImplWriteAnchor( const XclExpRoot& /*rRoot*/, const SdrObject* pSdr
 
 void XclObj::SetEscherShapeType( sal_uInt16 nType )
 {
-//ToDo: what about the other defined ot... types?
+//ToDo: what about the other defined or... types?
     switch ( nType )
     {
         case ESCHER_ShpInst_Line :
diff --git a/sc/source/ui/docshell/externalrefmgr.cxx b/sc/source/ui/docshell/externalrefmgr.cxx
index 2f76c4b7c049..a395daf2dd24 100644
--- a/sc/source/ui/docshell/externalrefmgr.cxx
+++ b/sc/source/ui/docshell/externalrefmgr.cxx
@@ -2614,7 +2614,7 @@ void ScExternalRefManager::maybeLinkExternalFile( sal_uInt16 nFileId, bool bDefe
     }
     // If a filter was already set (for example, loading the cached table),
     // don't call GetFilterName which has to access the source file.
-    // If filter detection is deferred, the next successfull loadSrcDocument()
+    // If filter detection is deferred, the next successful loadSrcDocument()
     // will update SrcFileData filter name.
     if (aFilter.isEmpty() && !bDeferFilterDetection)
         ScDocumentLoader::GetFilterName(*pFileName, aFilter, aOptions, true, false);
diff --git a/sfx2/qa/python/check_sidebar_registry.py b/sfx2/qa/python/check_sidebar_registry.py
index 24713d6f26d4..86f22f4fd44a 100644
--- a/sfx2/qa/python/check_sidebar_registry.py
+++ b/sfx2/qa/python/check_sidebar_registry.py
@@ -37,7 +37,7 @@ class CheckSidebarRegistry(unittest.TestCase):
         param.Name = "nodepath"
 
 
-        # Deck names consitency
+        # Deck names consistency
 
         param.Value = "org.openoffice.Office.UI.Sidebar/Content/DeckList"
 
@@ -51,7 +51,7 @@ class CheckSidebarRegistry(unittest.TestCase):
                 print("\nNon-consistent sidebar.xcu Deck registry names", nodeName, node.Id)
                 result = False
 
-        # panel names consitency
+        # panel names consistency
 
         param.Value = "org.openoffice.Office.UI.Sidebar/Content/PanelList"
 
diff --git a/slideshow/source/engine/animationnodes/animationaudionode.cxx b/slideshow/source/engine/animationnodes/animationaudionode.cxx
index 3076db710d16..5ee8860845b0 100644
--- a/slideshow/source/engine/animationnodes/animationaudionode.cxx
+++ b/slideshow/source/engine/animationnodes/animationaudionode.cxx
@@ -119,7 +119,7 @@ void AnimationAudioNode::deactivate_st( NodeState /*eDestState*/ )
     AnimationEventHandlerSharedPtr aHandler(
         std::dynamic_pointer_cast<AnimationEventHandler>( getSelf() ) );
     OSL_ENSURE( aHandler,
-                "could not cas self to AnimationEventHandler?" );
+                "could not cast self to AnimationEventHandler?" );
     getContext().mrEventMultiplexer.removeCommandStopAudioHandler( aHandler );
 
     // force-end sound
diff --git a/starmath/source/visitors.cxx b/starmath/source/visitors.cxx
index a0a337c79525..11606f74005f 100644
--- a/starmath/source/visitors.cxx
+++ b/starmath/source/visitors.cxx
@@ -401,7 +401,7 @@ void SmDrawingVisitor::Visit( SmRootSymbolNode* pNode )
     mrDev.SetLineColor( );
     aTmpDev.SetFont( pNode->GetFont( ) );
 
-    // since the width is always unscaled it corresponds ot the _original_
+    // since the width is always unscaled it corresponds to the _original_
     // _unscaled_ font height to be used, we use that to calculate the
     // bar height. Thus it is independent of the arguments height.
     // ( see display of sqrt QQQ versus sqrt stack{Q#Q#Q#Q} )
diff --git a/svx/source/fmcomp/fmgridcl.cxx b/svx/source/fmcomp/fmgridcl.cxx
index 8cdb4b59e055..ad34d09abec7 100644
--- a/svx/source/fmcomp/fmgridcl.cxx
+++ b/svx/source/fmcomp/fmgridcl.cxx
@@ -1832,7 +1832,7 @@ Sequence< Any> FmGridControl::getSelectionBookmarks()
         // Unfortunally the first call caused a propertyChanged(RECORDCOUNT) which resulted in a repaint of the
         // navigation bar and the grid. The latter itself will result in SeekRow calls. So after (successfully) returning
         // from the moveRelative the getPosition returns an invalid value. And so the SeekCursor fails.
-        // In the consequence ALL parts of code where two calls to the seek cursor are done, while the second call _relys_ on
+        // In the consequence ALL parts of code where two calls to the seek cursor are done, while the second call _relies_ on
         // the first one, should be secured against recursion, with a broad-minded interpretation of "recursion": if any of these
         // code parts is executed, no other should be accessible. But this sounds very difficult to achieve...
         // )
diff --git a/sw/source/core/ole/ndole.cxx b/sw/source/core/ole/ndole.cxx
index 1f6d5ce52f23..f9cb6df41e48 100644
--- a/sw/source/core/ole/ndole.cxx
+++ b/sw/source/core/ole/ndole.cxx
@@ -691,7 +691,7 @@ public:
 
 namespace {
 
-/// Task for parallely-executed task to load a chart model
+/// Task for parallelly-executed task to load a chart model
 class DeflateThread : public comphelper::ThreadTask
 {
     // the data to work on
diff --git a/sw/source/filter/html/htmlnumreader.cxx b/sw/source/filter/html/htmlnumreader.cxx
index 3b4ae766bdd3..fbda0537a119 100644
--- a/sw/source/filter/html/htmlnumreader.cxx
+++ b/sw/source/filter/html/htmlnumreader.cxx
@@ -398,7 +398,7 @@ void SwHTMLParser::EndNumBulList( HtmlTokenId nToken )
                 m_xDoc->ChgNumRuleFormats( *rInfo.GetNumRule() );
 
             // On the last append, the NumRule item and NodeNum object were copied.
-            // Now we need to delete them. ResetAttr deletes the NodeNum object aswell
+            // Now we need to delete them. ResetAttr deletes the NodeNum object as well
             m_pPam->GetNode().GetTextNode()->ResetAttr( RES_PARATR_NUMRULE );
 
             rInfo.Clear();
diff --git a/sw/source/filter/html/htmltab.cxx b/sw/source/filter/html/htmltab.cxx
index a8550415f72f..5f5d78fe52a3 100644
--- a/sw/source/filter/html/htmltab.cxx
+++ b/sw/source/filter/html/htmltab.cxx
@@ -1293,7 +1293,7 @@ void HTMLTable::FixFrameFormat( SwTableBox *pBox,
         {
             // If a cell spans multiple rows, a background to that row should be copied to the cell.
             // If it's a table in a table and that cell goes over the whole height of that table,
-            // the row's background has to be copied to the cell aswell,
+            // the row's background has to be copied to the cell as well,
             // since the line is gonna be GC-ed (correctly).
             if( nRowSpan > 1 || (this != m_pTopTable && nRowSpan==m_nRows) )
             {
@@ -2332,7 +2332,7 @@ void HTMLTable::MakeTable( SwTableBox *pBox, sal_uInt16 nAbsAvail,
 
     // Step 3: the actual column widths of this table are calculated (not tables in tables)
     // We need this now to decide if we need filler cells
-    // (Pass1 was needed because of this aswell)
+    // (Pass1 was needed because of this as well)
     m_pLayoutInfo->AutoLayoutPass2( nAbsAvail, nRelAvail, nAbsLeftSpace,
                                   nAbsRightSpace, nInhAbsSpace );
 
@@ -4755,7 +4755,7 @@ void SwHTMLParser::BuildTableCaption( HTMLTable *pCurTable )
 
     if( m_pTable==pCurTable )
     {
-        // On moving the caption later, the last paragraph isn't moved aswell.
+        // On moving the caption later, the last paragraph isn't moved as well.
         // That means, there has to be an empty paragraph at the end of the section
         if( m_pPam->GetPoint()->nContent.GetIndex() || bLFStripped )
             AppendTextNode( AM_NOSPACE );
diff --git a/writerfilter/source/dmapper/DomainMapper.cxx b/writerfilter/source/dmapper/DomainMapper.cxx
index 7253ae190581..fab6ff1d255e 100644
--- a/writerfilter/source/dmapper/DomainMapper.cxx
+++ b/writerfilter/source/dmapper/DomainMapper.cxx
@@ -3147,7 +3147,7 @@ void DomainMapper::lcl_text(const sal_uInt8 * data_, size_t len)
                     m_pImpl->CloseFieldCommand();
                     return;
                 case cFieldEnd:
-                    // In case there isn't any field seperator.
+                    // In case there isn't any field separator.
                     if ( m_pImpl->IsOpenFieldCommand() )
                         m_pImpl->CloseFieldCommand();
                     m_pImpl->PopFieldContext();


More information about the Libreoffice-commits mailing list
diff --git a/cui/source/tabpages/labdlg.cxx b/cui/source/tabpages/labdlg.cxx
index 348038e1123b..c0ca4fde6538 100644
--- a/cui/source/tabpages/labdlg.cxx
+++ b/cui/source/tabpages/labdlg.cxx
@@ -161,7 +161,7 @@ void SvxCaptionTabPage::dispose()
 void SvxCaptionTabPage::Construct()
 {
     // set rectangle and working area
-    DBG_ASSERT( pView, "No valid View transfered!" );
+    DBG_ASSERT( pView, "No valid View transferred!" );
 }
 
 
@@ -515,7 +515,7 @@ SvxCaptionTabDialog::SvxCaptionTabDialog(vcl::Window* pParent, const SdrView* pS
     , m_nPositionSizePageId(0)
     , m_nCaptionPageId(0)
 {
-    assert(pView); // No valid View transfered!
+    assert(pView); // No valid View transferred!
 
     //different positioning page in Writer
     if (nAnchorCtrls & (SvxAnchorIds::Paragraph | SvxAnchorIds::Character | SvxAnchorIds::Page | SvxAnchorIds::Fly))